Utilities
===================

Submodules
----------

taurex.util.emission module
---------------------------

.. automodule:: taurex.util.emission
   :members:
   :undoc-members:
   :show-inheritance:
taurex.util.math module
-----------------------

.. automodule:: taurex.util.math
   :members:
   :undoc-members:
   :show-inheritance:
taurex.util.util module
-----------------------

.. automodule:: taurex.util.util
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: taurex.util
   :members:
   :undoc-members:
   :show-inheritance:
